.. man_aa.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2022 Róbert Čerňanský



.. User documentation - aa manual page



===========
AutoArchive
===========

Synopsis
========

.. include:: ../general/description.rst
   :start-after: begin_synopsis
   :end-before: end_synopsis



Description
===========

.. include:: ../general/description.rst
   :start-after: begin_description
   :end-before: end_description



Options
=======

.. include:: ../general/description.rst
   :start-after: begin_usage
   :end-before: end_usage

**List of command line options**

.. include:: ../general/description.rst
   :start-after: begin_options
   :end-before: end_options



Exit Codes
==========

.. include:: ../general/description.rst
   :start-after: begin_exit_codes
   :end-before: end_exit_codes



Files
=====

.. include:: ../general/description.rst
   :start-after: begin_files
   :end-before: end_files



Examples
========

.. include:: ../general/examples.rst
   :start-after: begin_examples
   :end-before: end_examples
.. include:: ../general/examples.rst
   :start-after: begin_examples_configuring
   :end-before: end_examples_configuring
.. include:: ../general/examples.rst
   :start-after: begin_examples_backup_creation
   :end-before: end_examples_backup_creation

Backup Keeping
--------------

.. include:: ../general/examples.rst
   :start-after: begin_examples_backup_keeping
   :end-before: end_examples_backup_keeping



License
=======

.. include:: ../general/general_information.rst
   :start-after: begin_license
   :end-before: end_license



See Also
========

|config_file_ref|, |arch_spec_ref|, |tar_ref|, *gzip*\(1), *bzip2*\(1), *xz*\(1), *zstd*\(1)



.. |configs_reference_text| replace:: *aa.conf*\(5) and *aa_arch_spec*\(5)

.. |tar_ref| replace:: *tar*\(1)

.. |gnu_tar_ref| replace:: **GNU tar**

.. |config_file_ref| replace:: *aa.conf*\(5)

.. |arch_spec_ref| replace:: *aa_arch_spec*\(5)
